@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-
 import numpy as np
-import talib
 from iqsopenapi import *
 
 def on_init(ctx):
@@ -31,11 +29,11 @@ def on_init(ctx):
 
     trades = ctx.get_trades()
 
-    order = ctx.insert_order('rb2010.SHFE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,3)
+    order = ctx.insert_order('rb2010.SHFE',OrderSide.Buy,OrderType.LMT,Offset.Open,3530,3)
 
     order1 = ctx.cancel_order(order)
 
-    order2 = ctx.get_order(order1.order_id)
+    order2 = ctx.get_order(order.order_id)
 
     pass
     
@@ -56,7 +54,7 @@ def cal_range(ctx):
     High = np.array([bar.high for bar in last_bars])
     Low = np.array([bar.low for bar in last_bars])
     Close = np.array([bar.close for bar in last_bars])
-    Range = talib.ATR(High,Low,Close,timeperiod=ctx.f1-1)[-1]
+    Range = talib.ATR(High,Low,Close,timeperiod=ctx.f1 - 1)[-1]
     return Range
     
 def change_contract(ctx):
@@ -72,6 +70,9 @@ def on_tick(ctx,tick):
 
 def on_order(ctx,order):
     logger.info('on order:{0},{1},{2},{3}'.format(order.symbol,order.side.name,order.offset.name,order.status.name))
+
+def on_trade(ctx,trade):
+    logger.info('on trade:{0},{1},{2},{3},{4}'.format(trade.symbol,trade.side.name,trade.offset.name,trade.quantity,trade.price))
     
 def on_bar(ctx,bar):
     logger.info('bar:{0},{1},{2}'.format(bar.symbol,bar.local_time,bar.close))
@@ -92,24 +93,39 @@ def on_bar(ctx,bar):
     #    if not (bar.high > ctx.up and bar.low < ctx.down):
     #        if ctx.last_high <= ctx.up and bar.open >= ctx.up:
     #            acc = ctx.get_account()
-    #            quantity = int(acc.available / ctx.up / ctx.lots / 0.01 * ctx.bet_size)
+    #            quantity = int(acc.available / ctx.up / ctx.lots / 0.01 *
+    #            ctx.bet_size)
     #            if quantity:
     #                ctx.insert_smart_order(ctx.domi_contract,quantity)
     #        if ctx.last_low >= ctx.down and bar.open <= ctx.down:
     #            acc = ctx.get_account()
-    #            quantity = int(acc.available / ctx.up / ctx.lots / 0.01 * ctx.bet_size)
+    #            quantity = int(acc.available / ctx.up / ctx.lots / 0.01 *
+    #            ctx.bet_size)
     #            if quantity:
     #                ctx.insert_smart_order(ctx.domi_contract,-quantity)
     #    ctx.last_high = bar.high
     #    ctx.last_low = bar.low
-
 config = {
     "runtime":"DEBUG",
-    "run_type":"PAPER_TRADING",
-    "logfile":r"D:\logs\test\strategy.log",
+    "run_type":"LIVE_TRADING",
+    "log":{
+            'level':'INFO',
+            'file' :r"D:\logs\test\strategy.log",
+        },
+    #"ext_notify":{
+    #        "type":"websocket",
+    #        "address":"ws://localhost:14002/"
+    #    },
+    #"acct_info":{
+    #        "strategy_id":"21",
+    #        "account":"10030"
+    #    }
     "acct_info":{
-            "strategy_id":"21",
-            "account":"10030"
+            "strategy_id":"1021",
+            "account":"060031",
+            "password":"Wx@123456",
+            "comp_counter": 96,
+            "broker_type":152
         }
 }
 run_func(**globals())
\ No newline at end of file
