@@ -58,7 +58,7 @@ class PaperTradeApi(ITradeApi):
                 subRet = self.Subscribe(*self.__subscribes)
                 logger.debug("连接成功，订阅完成：{0}".format(subRet))
         except Exception as e:
-            logger.error(e)
+            logger.error('paper trade subscribe exception',e)
 
     def __Subscribe(self):
         id = uuid.uuid1().hex
@@ -142,19 +142,24 @@ class PaperTradeApi(ITradeApi):
 
         url = Environment.get_instance().get_apiurl('api/PaperTrade/SendOrder')
         resp = httpJsonPost(url, params)
+        logger.info("sendorder complated，param:{0},resp:{1}".format(json.dumps(params,ensure_ascii=False),resp))
         if not resp:
             logger.error("response is empty:{0},{1}".format(url,json.dumps(params,ensure_ascii=False)))
             return None
         js = json.loads(resp,encoding='utf-8')
+
+        neworder = copy(order)
         if js.get('error_no') != 0:
             logger.error("sendorder failed:{0},{1},{2}".format(url,json.dumps(params,ensure_ascii=False),resp))
-            return None
-
-        orderId = js.get('data')['orderId']
-        order.order_id = str(orderId)
-        self.__event_bus.publish_event(order_event)
-        logger.info("sendorder complated，param:{0},resp:{1}".format(json.dumps(params,ensure_ascii=False),resp))
-        return order
+            neworder.status = OrderStatus.Rejected
+            neworder.note = js.get('error_info')
+        else:
+            orderId = js.get('data')['orderId']
+            neworder.order_id = str(orderId)
+            neworder.status = OrderStatus.Sended
+        neworder_event = Event(EVENT.On_Order,data = neworder)
+        self.__event_bus.publish_event(neworder_event)
+        return neworder
 
     def CancelOrder(self,order):
         """撤单"""
@@ -180,11 +185,15 @@ class PaperTradeApi(ITradeApi):
         js = json.loads(resp,encoding='utf-8')
         if js.get('error_no') != 0:
             logger.error("cancel order failed:{0},{1},{2}".format(url,json.dumps(params,ensure_ascii=False),resp))
-            return None
 
         self.__cache.clear()
 
-        return self.GetOrder(order.order_id)
+        newCancelOrder = self.GetOrder(order.order_id)
+
+        newCancelOrder_event = Event(EVENT.On_Order,data = newCancelOrder)
+        self.__event_bus.publish_event(newCancelOrder_event)
+
+        return newCancelOrder
 
     def GetAccount(self):
         """获取资产信息"""
@@ -342,9 +351,9 @@ class PaperTradeApi(ITradeApi):
         trade.trade_id = item['eid']
         trade.side = OrderSide(item['osd'])
         trade.price = item['p']
-        trade.offset = item['oft']
+        trade.offset = Offset(item['oft'])
         trade.quantity = item['q']
-        trade.filled_time = item['ft']
+        trade.filled_time = datetime.datetime.strptime(item['ft'],'%Y-%m-%d %H:%M:%S')
         return trade
 
     def __ToPos(self, item):
