@@ -100,7 +100,7 @@ class WebSocketClient(object):
                  self.__lastActiveTime = datetime.datetime.now()
                  self.__unhandledQueue.put(result)
             except Exception as e:
-                logger.error(e)
+                logger.error(self.config.address + 'receive msg exception',e)
                 time.sleep(1)
 
     def __HandleMsg(self):
@@ -113,7 +113,7 @@ class WebSocketClient(object):
                     continue
                 self.__RaiseMessage(msg)
             except Exception as e:
-                logger.error(e)
+                logger.error(self.config.address + 'handle msg exception',e)
                 time.sleep(1)
     
     def __AutoHeartBeat(self):
@@ -134,7 +134,7 @@ class WebSocketClient(object):
                 self.Send(self.config.hbContent)
                 logger.debug("send heart beat:{0}".format(self.config.address))
             except Exception as e:
-                logger.error(e)
+                logger.error(self.config.address + 'heart beat exception',e)
                 self.__Close()
 
     def __RaiseMessage(self,msg):
@@ -150,12 +150,12 @@ class WebSocketClient(object):
                 self.__wsclinet.close()
             self.__wsclinet = None
         except Exception as e:
-            logger.error(e)
+            logger.error(self.config.address +'close connect excetpion',e)
         
         
 if __name__ == '__main__':
     cfg = websocketCfg()
-    cfg.address = "wss://dev_quotegateway.inquantstudio.com"
+    cfg.address = "wss://dev_apigateway.inquantstudio.com/usermsg/"
     cfg.hbContent = json.dumps({ 'requestType' : 'HeartBeat','reqID' : '' })
     cfg.recvCallback = lambda msg:logger.info(msg)
 
